
-- BOOST curse: makes the blocks fall very fast for a few seconds ------------

ID_CURSE_BOOST=10

function boost_do_curse(sent)
    if sent==0 then
        u61_send_curse(ID_CURSE_BOOST)
    else
        u61_register_curse(ID_CURSE_BOOST,500,0)
    end
end

function boost_time_callback()
    if u61_get_curse_age(ID_CURSE_BOOST)>=0 then
        translation_y(1)
    end
end

